import {
  select,
  csv,
  scaleLinear,
  extent,  
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


const render = data => {
  
  const yValue = d => d.averageprice;
  const yAxisLabel = "Average Price";
	const xValue = d => d.totalvolume;
  const xAxisLabel = "Total Volume";
  const margin = {top:100, right:100, bottom:90, left:150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const circleRadius = 8;
  const title = 'Avocado - Avg Price vs Total Volume';
  
  
  const xScale = scaleLinear() // maps domain onto range
  .domain(extent(data, xValue)) //min(data, xValue),max(data, xValue)])
  .range([0, innerWidth]) // min max
  .nice();
  
  const yScale = scaleLinear() // categorical variables
  .domain(extent(data, yValue))
  .range([innerHeight, 0]) // min max
  .nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxisTickFormat = number => 
  	format('.1s')(number);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
   .tickFormat(xAxisTickFormat)
  	.tickPadding(5);
 
  const yAxis = axisLeft(yScale)
  .tickSize(-innerWidth)
  .tickPadding(5);
  
  const yAxisG = g
  	.append('g')
    .call(yAxis);
  
  yAxisG
  	.selectAll('.domain')
  	.remove();
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
    .attr('y', -93)
  	.attr('fill', 'black')
    .attr('x', -innerHeight/2)
    .attr('transform', `rotate(-90)`)
    .attr('text-anchor', 'middle')
    .text(yAxisLabel);
  


  const xAxisG = g.append('g')
    .call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
  

  
 
  
  xAxisG.select('.domain').remove();
 
  xAxisG.append('text')
  	.attr('class', 'axis-label')
    .attr('y', 75)
  	.attr('fill', 'black')
    .attr('x', innerWidth/2)
    .text(xAxisLabel);

 
  g.selectAll('circle') // currently empty set of circles
  .data(data) //the data, bound to empty circles. This is the 'd3 data join'
  .enter() // (enter) - creates 1 'slot' for each row
  .append('circle') 
  	.attr('cy', d => yScale(yValue(d)))
    .attr('cx', d => xScale(xValue(d))) 
    .attr('r', circleRadius);
  
 //add the title
  g.append('text')
    .attr('class', 'title')
    .attr('y', -10)
	  .attr('fill', 'black')
    .text(title);
};

d3.csv('https://vizhub.com/leorawe/datasets/avocados-no-quotes.csv')
  .then(data => {
    data.forEach(d => { 
      d.averageprice = +d.averageprice;
      d.totalvolume = +d.totalvolume;
      d.totalbags = +d.totalbags;
      console.log(d.totalbags);
   });
  render(data);
  });


